<?php
/**
 * Namespace Teknisa\Logic\IntNutrientes\Controllers
 *
 * PHP version 5
 *
 * @category Php
 * @package  Tecfood\Integracao\Controllers
 * @author   andreteixeira <andre.teixeira@teknisa.com>
 * @license  www.teknisa.com Teknisa
 * @link     http://localhost:9090/tecfood
 */
namespace Teknisa\Logic\IntNutrientes\Controllers;

use Geral\Entities\Organizacao;
use Teknisa\Entities\SitProdutoint as SitProdutointEntity;
use Teknisa\Logic\IntNutrientes\Services\EnviaProdutos as EnviaProdutosService;
use Teknisa\Logic\SIT\Request;
use Teknisa\Logic\SIT\Response;
use Teknisa\Repositories\SitProdutoint;


/**
 * Class EnviaProdutos para o Cliente
 *
 * PHP version 5
 *
 * @category Php
 * @package  Teknisa\Logic\IntNutrientes\Controllers
 * @author   andreteixeira <andre.teixeira@teknisa.com>
 * @license  www.teknisa.com Teknisa
 * @link     http://localhost:9090/tecfood
 */
class EnviaProdutos
{

    /**
     * Controla o Envio de Produtos para o Cliente
     * Esta classe se refere à visão Teknisa: essa ação será executada quando o
     * cliente RECEBER os produtos (Rota: recProduto).
     *
     * @param Request  $request  Request
     * @param Response $response Response
     */
    public function enviaProdutos (Request $request, Response $response)
    {
        $json = $request->getData();

        if (empty($json) === false) {
            if (!is_array($json)) {
                $json = json_decode($json, true);
            }

            $prods = self::validaOrganizacao($json['NRORGINT']);

            if ($prods) {
                if ($json['PENDENTE'] == '1') {
                    //Busca os Produtos das Remessas Pendentes
                    $prods = SitProdutoint::sqlBuscaProdutosPendentes(
                        $json['NRORG'], $json['NRORGINT'], $json['NRREMESSA']
                    );
                } else {
                    //Busca os Produtos Liberados
                    $prods = SitProdutoint::sqlProdutosLiberados(
                        $json['NRORG'], $json['NRORGINT']
                    );
                }

                //Divide os produtos na quantidade definida no JSON
                $prods = array_chunk($prods, $json['MAXPRODRET']);

                //Envia os Produtos Liberados
                $prod = EnviaProdutosService::enviaProdutos(
                    $prods[0], $json['NRORG'], $json['NRREMESSA'], $json['NRORGINT']
                );
            } else {
                $prod = tk_get_message_by_name('msg_ger07600_msgErroOrganizacao');
            }


        } else {
            //$prod = array('msg_ger07600_parametroIncorreto', array());
            $prod = tk_get_message_by_name('msg_ger07600_parametroIncorreto');
        }

        //Gera Response
        $response->setData($prod);
    }

    /**
     * Verifica se a Organizacao passada por parametro é válida.
     * Retorna true se a Organização existe e está ativa.
     *
     * @param String $nrorgint Organizaçao
     *
     * @return bool.
     */
    public static function validaOrganizacao ($nrorgint)
    {
        $reg = Organizacao::getObjectByWhere(
            "NRORG = ?",
            array($nrorgint)
        );

        $retorno = false;
        if ($reg instanceof Organizacao) {
            if ($reg->getIdativo() == 'S') {
                $retorno = true;
            }
        }

        return $retorno;
    }
}
